Arguments
formula
The regression formula (e.g. income ~ employment + old.turnover if income is survey variable and employment and old.turnover are auxiliary variables).
data
A data frame including the variables in formula, and gregwt (generalized regression estimator weight), and regwt (weight to be used in regression - will be set to 1 if missing).
Q
The tuning parameter where large Q corresponds to no outlier treatment, and small Q corresponds to many outliers being flagged.
Qname
Gives a variable name on data which contains a separate tuning parameter Q for every observation (either Q or Qname should be specified but not both).
maxit
The maximum number of iterations.
stop
Set to T to open a browser window (for debugging purposes)